==> serde_json_lodash-0.1.14.crate: serde_json_lodash-0.1.14/src/lang/mod.rs <==
#[doc(hidden)]
pub fn cast_array() {
    todo!()
}
#[doc(hidden)]
pub use cast_array as castArray;
#[doc(hidden)]
pub fn clone() {
    todo!()
}
#[doc(hidden)]
pub fn clone_deep() {
    todo!()
}
#[doc(hidden)]
pub use clone_deep as cloneDeep;
#[doc(hidden)]
pub fn clone_deep_with() {
    todo!()
}
#[doc(hidden)]
pub use clone_deep_with as cloneDeepWith;
#[doc(hidden)]
pub fn clone_with() {
    todo!()
}
#[doc(hidden)]
pub use clone_with as cloneWith;
#[doc(hidden)]
pub fn conforms_to() {
    todo!()
}
#[doc(hidden)]
pub use conforms_to as conformsTo;
#[doc(hidden)]
pub fn eq() {
    todo!()
}
#[doc(hidden)]
pub fn gt() {
    todo!()
}
#[doc(hidden)]
pub fn gte() {
    todo!()
}
#[doc(hidden)]
pub fn is_arguments() {
    todo!()
}
#[doc(hidden)]
pub use is_arguments as isArguments;
#[doc(hidden)]
pub fn is_array() {
    todo!()
}
#[doc(hidden)]
pub use is_array as isArray;
#[doc(hidden)]
pub fn is_array_buffer() {
    todo!()
}
#[doc(hidden)]
pub use is_array_buffer as isArrayBuffer;
#[doc(hidden)]
pub fn is_array_like() {
    todo!()
}
#[doc(hidden)]
pub use is_array_like as isArrayLike;
#[doc(hidden)]
pub fn is_array_like_object() {
    todo!()
}
#[doc(hidden)]
pub use is_array_like_object as isArrayLikeObject;
#[doc(hidden)]
pub fn is_boolean() {
    todo!()
}
#[doc(hidden)]
pub use is_boolean as isBoolean;
#[doc(hidden)]
pub fn is_buffer() {
    todo!()
}
#[doc(hidden)]
pub use is_buffer as isBuffer;
#[doc(hidden)]
pub fn is_date() {
    todo!()
}
#[doc(hidden)]
pub use is_date as isDate;
#[doc(hidden)]
pub fn is_element() {
    todo!()
}
#[doc(hidden)]
pub use is_element as isElement;
#[doc(hidden)]
pub fn is_empty() {
    todo!()
}
#[doc(hidden)]
pub use is_empty as isEmpty;
#[doc(hidden)]
pub fn is_equal() {
    todo!()
}
#[doc(hidden)]
pub use is_equal as isEqual;
#[doc(hidden)]
pub fn is_equal_with() {
    todo!()
}
#[doc(hidden)]
pub use is_equal_with as isEqualWith;
#[doc(hidden)]
pub fn is_error() {
    todo!()
}
#[doc(hidden)]
pub use is_error as isError;
#[doc(hidden)]
pub fn is_finite() {
    todo!()
}
#[doc(hidden)]
pub use is_finite as isFinite;
#[doc(hidden)]
pub fn is_function() {
    todo!()
}
#[doc(hidden)]
pub use is_function as isFunction;
#[doc(hidden)]
pub fn is_integer() {
    todo!()
}
#[doc(hidden)]
pub use is_integer as isInteger;
#[doc(hidden)]
pub fn is_length() {
    todo!()
}
#[doc(hidden)]
pub use is_length as isLength;
#[doc(hidden)]
pub fn is_map() {
    todo!()
}
#[doc(hidden)]
pub use is_map as isMap;
#[doc(hidden)]
pub fn is_match() {
    todo!()
}
#[doc(hidden)]
pub use is_match as isMatch;
#[doc(hidden)]
pub fn is_match_with() {
    todo!()
}
#[doc(hidden)]
pub use is_match_with as isMatchWith;
#[doc(hidden)]
pub fn is_nan() {
    todo!()
}
#[doc(hidden)]
pub use is_nan as isNaN;
#[doc(hidden)]
pub fn is_native() {
    todo!()
}
#[doc(hidden)]
pub use is_native as isNative;
#[doc(hidden)]
pub fn is_nil() {
    todo!()
}
#[doc(hidden)]
pub use is_nil as isNil;
#[doc(hidden)]
pub fn is_null() {
    todo!()
}
#[doc(hidden)]
pub use is_null as isNull;
#[doc(hidden)]
pub fn is_number() {
    todo!()
}
#[doc(hidden)]
pub use is_number as isNumber;
#[doc(hidden)]
pub fn is_object() {
    todo!()
}
#[doc(hidden)]
pub use is_object as isObject;
#[doc(hidden)]
pub fn is_object_like() {
    todo!()
}
#[doc(hidden)]
pub use is_object_like as isObjectLike;
#[doc(hidden)]
pub fn is_plain_object() {
    todo!()
}
#[doc(hidden)]
pub use is_plain_object as isPlainObject;
#[doc(hidden)]
pub fn is_reg_exp() {
    todo!()
}
#[doc(hidden)]
pub use is_reg_exp as isRegExp;
#[doc(hidden)]
pub fn is_safe_integer() {
    todo!()
}
#[doc(hidden)]
pub use is_safe_integer as isSafeInteger;
#[doc(hidden)]
pub fn is_set() {
    todo!()
}
#[doc(hidden)]
pub use is_set as isSet;
#[doc(hidden)]
pub fn is_string() {
    todo!()
}
#[doc(hidden)]
pub use is_string as isString;
#[doc(hidden)]
pub fn is_symbol() {
    todo!()
}
#[doc(hidden)]
pub use is_symbol as isSymbol;
#[doc(hidden)]
pub fn is_typed_array() {
    todo!()
}
#[doc(hidden)]
pub use is_typed_array as isTypedArray;
#[doc(hidden)]
pub fn is_undefined() {
    todo!()
}
#[doc(hidden)]
pub use is_undefined as isUndefined;
#[doc(hidden)]
pub fn is_weak_map() {
    todo!()
}
#[doc(hidden)]
pub use is_weak_map as isWeakMap;
#[doc(hidden)]
pub fn is_weak_set() {
    todo!()
}
#[doc(hidden)]
pub use is_weak_set as isWeakSet;
#[doc(hidden)]
pub fn lt() {
    todo!()
}
#[doc(hidden)]
pub fn lte() {
    todo!()
}
#[doc(hidden)]
pub fn to_array() {
    todo!()
}
#[doc(hidden)]
pub use to_array as toArray;
#[doc(hidden)]
pub fn to_finite() {
    todo!()
}
#[doc(hidden)]
pub use to_finite as toFinite;
#[doc(hidden)]
pub fn to_integer() {
    todo!()
}
#[doc(hidden)]
pub use to_integer as toInteger;
#[doc(hidden)]
pub fn to_length() {
    todo!()
}
#[doc(hidden)]
pub use to_length as toLength;
#[doc(hidden)]
pub fn to_number() {
    todo!()
}
#[doc(hidden)]
pub use to_number as toNumber;
#[doc(hidden)]
pub fn to_plain_object() {
    todo!()
}
#[doc(hidden)]
pub use to_plain_object as toPlainObject;
#[doc(hidden)]
pub fn to_safe_integer() {
    todo!()
}
#[doc(hidden)]
pub use to_safe_integer as toSafeInteger;
mod to_string;
pub use to_string::*;

==> serde_json_lodash-0.1.16.crate: serde_json_lodash-0.1.16/src/lang/mod.rs <==
#[doc(hidden)]
pub fn cast_array() {
    todo!()
}
#[doc(hidden)]
pub use cast_array as castArray;
#[doc(hidden)]
pub fn clone() {
    todo!()
}
#[doc(hidden)]
pub fn clone_deep() {
    todo!()
}
#[doc(hidden)]
pub use clone_deep as cloneDeep;
#[doc(hidden)]
pub fn clone_deep_with() {
    todo!()
}
#[doc(hidden)]
pub use clone_deep_with as cloneDeepWith;
#[doc(hidden)]
pub fn clone_with() {
    todo!()
}
#[doc(hidden)]
pub use clone_with as cloneWith;
#[doc(hidden)]
pub fn conforms_to() {
    todo!()
}
#[doc(hidden)]
pub use conforms_to as conformsTo;
#[doc(hidden)]
pub fn eq() {
    todo!()
}
#[doc(hidden)]
pub fn gt() {
    todo!()
}
#[doc(hidden)]
pub fn gte() {
    todo!()
}
#[doc(hidden)]
pub fn is_arguments() {
    todo!()
}
#[doc(hidden)]
pub use is_arguments as isArguments;
#[doc(hidden)]
pub fn is_array() {
    todo!()
}
#[doc(hidden)]
pub use is_array as isArray;
#[doc(hidden)]
pub fn is_array_buffer() {
    todo!()
}
#[doc(hidden)]
pub use is_array_buffer as isArrayBuffer;
#[doc(hidden)]
pub fn is_array_like() {
    todo!()
}
#[doc(hidden)]
pub use is_array_like as isArrayLike;
#[doc(hidden)]
pub fn is_array_like_object() {
    todo!()
}
#[doc(hidden)]
pub use is_array_like_object as isArrayLikeObject;
#[doc(hidden)]
pub fn is_boolean() {
    todo!()
}
#[doc(hidden)]
pub use is_boolean as isBoolean;
#[doc(hidden)]
pub fn is_buffer() {
    todo!()
}
#[doc(hidden)]
pub use is_buffer as isBuffer;
#[doc(hidden)]
pub fn is_date() {
    todo!()
}
#[doc(hidden)]
pub use is_date as isDate;
#[doc(hidden)]
pub fn is_element() {
    todo!()
}
#[doc(hidden)]
pub use is_element as isElement;
#[doc(hidden)]
pub fn is_empty() {
    todo!()
}
#[doc(hidden)]
pub use is_empty as isEmpty;
#[doc(hidden)]
pub fn is_equal() {
    todo!()
}
#[doc(hidden)]
pub use is_equal as isEqual;
#[doc(hidden)]
pub fn is_equal_with() {
    todo!()
}
#[doc(hidden)]
pub use is_equal_with as isEqualWith;
#[doc(hidden)]
pub fn is_error() {
    todo!()
}
#[doc(hidden)]
pub use is_error as isError;
#[doc(hidden)]
pub fn is_finite() {
    todo!()
}
#[doc(hidden)]
pub use is_finite as isFinite;
#[doc(hidden)]
pub fn is_function() {
    todo!()
}
#[doc(hidden)]
pub use is_function as isFunction;
#[doc(hidden)]
pub fn is_integer() {
    todo!()
}
#[doc(hidden)]
pub use is_integer as isInteger;
#[doc(hidden)]
pub fn is_length() {
    todo!()
}
#[doc(hidden)]
pub use is_length as isLength;
#[doc(hidden)]
pub fn is_map() {
    todo!()
}
#[doc(hidden)]
pub use is_map as isMap;
#[doc(hidden)]
pub fn is_match() {
    todo!()
}
#[doc(hidden)]
pub use is_match as isMatch;
#[doc(hidden)]
pub fn is_match_with() {
    todo!()
}
#[doc(hidden)]
pub use is_match_with as isMatchWith;
#[doc(hidden)]
pub fn is_nan() {
    todo!()
}
#[doc(hidden)]
pub use is_nan as isNaN;
#[doc(hidden)]
pub fn is_native() {
    todo!()
}
#[doc(hidden)]
pub use is_native as isNative;
#[doc(hidden)]
pub fn is_nil() {
    todo!()
}
#[doc(hidden)]
pub use is_nil as isNil;
#[doc(hidden)]
pub fn is_null() {
    todo!()
}
#[doc(hidden)]
pub use is_null as isNull;
#[doc(hidden)]
pub fn is_number() {
    todo!()
}
#[doc(hidden)]
pub use is_number as isNumber;
#[doc(hidden)]
pub fn is_object() {
    todo!()
}
#[doc(hidden)]
pub use is_object as isObject;
#[doc(hidden)]
pub fn is_object_like() {
    todo!()
}
#[doc(hidden)]
pub use is_object_like as isObjectLike;
#[doc(hidden)]
pub fn is_plain_object() {
    todo!()
}
#[doc(hidden)]
pub use is_plain_object as isPlainObject;
#[doc(hidden)]
pub fn is_reg_exp() {
    todo!()
}
#[doc(hidden)]
pub use is_reg_exp as isRegExp;
#[doc(hidden)]
pub fn is_safe_integer() {
    todo!()
}
#[doc(hidden)]
pub use is_safe_integer as isSafeInteger;
#[doc(hidden)]
pub fn is_set() {
    todo!()
}
#[doc(hidden)]
pub use is_set as isSet;
#[doc(hidden)]
pub fn is_string() {
    todo!()
}
#[doc(hidden)]
pub use is_string as isString;
#[doc(hidden)]
pub fn is_symbol() {
    todo!()
}
#[doc(hidden)]
pub use is_symbol as isSymbol;
#[doc(hidden)]
pub fn is_typed_array() {
    todo!()
}
#[doc(hidden)]
pub use is_typed_array as isTypedArray;
#[doc(hidden)]
pub fn is_undefined() {
    todo!()
}
#[doc(hidden)]
pub use is_undefined as isUndefined;
#[doc(hidden)]
pub fn is_weak_map() {
    todo!()
}
#[doc(hidden)]
pub use is_weak_map as isWeakMap;
#[doc(hidden)]
pub fn is_weak_set() {
    todo!()
}
#[doc(hidden)]
pub use is_weak_set as isWeakSet;
#[doc(hidden)]
pub fn lt() {
    todo!()
}
#[doc(hidden)]
pub fn lte() {
    todo!()
}
#[doc(hidden)]
pub fn to_array() {
    todo!()
}
#[doc(hidden)]
pub use to_array as toArray;
#[doc(hidden)]
pub fn to_finite() {
    todo!()
}
#[doc(hidden)]
pub use to_finite as toFinite;
#[doc(hidden)]
pub fn to_integer() {
    todo!()
}
#[doc(hidden)]
pub use to_integer as toInteger;
#[doc(hidden)]
pub fn to_length() {
    todo!()
}
#[doc(hidden)]
pub use to_length as toLength;
#[doc(hidden)]
pub fn to_number() {
    todo!()
}
#[doc(hidden)]
pub use to_number as toNumber;
#[doc(hidden)]
pub fn to_plain_object() {
    todo!()
}
#[doc(hidden)]
pub use to_plain_object as toPlainObject;
mod to_safe_integer;
pub use to_safe_integer::*;
mod to_string;
pub use to_string::*;
